@@ -12,7 +12,7 @@ class Resource:
     """
     Base class for any resource.
 
-    It is mainly responsible of passing a reference to the client
+    It is mainly responsible for passing a reference to the client
     to this class when instantiated, and transmit the json data into
     attributes
     """
@@ -20,20 +20,15 @@ class Resource:
     id: int
     type: str
 
-    _date_fields = set()
-    _datetime_fields = set()
+    _fields_parsers = {}
 
     def __init__(self, client, json):
-        # Parse data and datetime fields
-        for fields_list, parse_func in [
-            (self._date_fields, parse_date),
-            (self._datetime_fields, parse_datetime),
-        ]:
-            for field_name in fields_list:
-                if field_name in json:
-                    json[field_name] = parse_func(json[field_name])
-        self._fields = tuple(json.keys())
         self.client = client
+        for field_name in json.keys():
+            parse_func = getattr(self, f"_parse_{field_name}", None)
+            if callable(parse_func):
+                json[field_name] = parse_func(json[field_name])
+        self._fields = tuple(json.keys())
         for key in json:
             setattr(self, key, json[key])
 
@@ -44,16 +39,18 @@ class Resource:
         return f"<{self.__class__.__name__}: {name or title or id_}>"
 
     def as_dict(self):
-        """
-        Convert resource to dictionary
-        """
+        """Convert resource to dictionary."""
         result = {}
         for key in self._fields:
             value = getattr(self, key)
             if isinstance(value, list):
                 value = [i.as_dict() if isinstance(i, Resource) else i for i in value]
-            if isinstance(value, Resource):
+            elif isinstance(value, Resource):
                 value = value.as_dict()
+            elif isinstance(value, dt.datetime):
+                value = f"{value:%Y-%m-%d %H:%M:%S}"
+            elif isinstance(value, dt.date):
+                value = value.isoformat()
             result[key] = value
         return result
 
@@ -126,7 +123,10 @@ class Album(Resource):
     contributors: List["Artist"]
     artist: "Artist"
 
-    _date_fields = {"release_date"}
+    _parse_release_date = staticmethod(parse_date)
+
+    def _parse_contributors(self, raw_value):
+        return [Artist(client=self.client, json=val) for val in raw_value]
 
     def get_artist(self):
         """
@@ -309,7 +309,10 @@ class Track(Resource):
     artist: "Artist"
     album: "Album"
 
-    _date_fields = {"release_date"}
+    _parse_release_date = staticmethod(parse_date)
+
+    def _parse_contributors(self, raw_value):
+        return [Artist(client=self.client, json=val) for val in raw_value]
 
     def get_artist(self):
         """
@@ -354,7 +357,8 @@ class User(Resource):
     explicit_content_levels_available: Optional[List[str]]
     tracklist: str
 
-    _date_fields = {"birthday", "inscription_date"}
+    _parse_birthday = staticmethod(parse_date)
+    _parse_inscription_date = staticmethod(parse_date)
 
     def get_albums(self, **kwargs):
         """
@@ -645,4 +649,4 @@ class Episode(Resource):
     picture_xl: str
     podcast: Podcast
 
-    _datetime_fields = {"release_date"}
+    _parse_release_date = staticmethod(parse_datetime)
